#!/bin/bash

################################################################################
# Installation Script of UniMRCP Server with Orange Plugin 
#
# This script installs or updates packages of UniMRCP server with Orange plugin.
#

PACKAGE_ARCH="x86_64"
PACKAGE_RH_VERSION="7"
PACKAGE_DISTRIB="el$PACKAGE_RH_VERSION"
PACKAGE_VERSION="1"

APR_VERSION="1.5.2"
APR_UTIL_VERSION="1.5.4"
SOFIA_SIP_VERSION="1.12.12"
UNIMRCP_VERSION="1.7.0"
UNIGRPC_VERSION="1.30.3"
UNIGRPC_DEPS_VERSION="1.30.2"
UNILICNODEGEN_VERSION="1.0.0"
UNIMRCP_ORANGE_VERSION="1.7.7"
UMC_ADDONS_VERSION="1.7.1"

echo ""
echo "======================================================================"
echo "      Installation Script of UniMRCP Server and Orange Plugin         "
echo "======================================================================"
echo ""

################################################################################
# Step 1: Determine if the packages are being installed on a supported distribution.

echo -n "Determining Linux distribution... "
# First, determine RPM providing /etc/redhat-release.
DISTRIB_RPM=`rpm -q --whatprovides /etc/redhat-release`
if [[ -z "$DISTRIB_RPM" ]]; then
    echo "/etc/redhat-release not available."
    echo "The packages can be installed only on a RedHat-based distribution."
    echo ""
    exit 1
fi
echo "$DISTRIB_RPM."
# Next, determine distribution version (6, 6SERVER, 7, 7SERVER,...).
DISTRIB_VERSION=`rpm -q --queryformat '%{VERSION}' $DISTRIB_RPM | cut -c1`
if [[ "$DISTRIB_VERSION" != "$PACKAGE_RH_VERSION" ]]; then
    # Not appropriate version of RedHat-based distribution
    echo "The packages are built for $PACKAGE_RH_VERSION while $DISTRIB_VERSION is determined"
    echo ""
    exit 1
fi
# Determine distribution name (RedHat|CentOS).
DISTRIB_PREFIX=`rpm -q --queryformat '%{NAME}' $DISTRIB_RPM | cut -c1-3`
case $DISTRIB_PREFIX in
red)
    DISTRIB="RedHat"
    ;;
cen)
    DISTRIB="CentOS"
    ;;
*)
    # Unsupported RedHat-based Linux Distribution
    echo "Unsupported distribution prefix: $DISTRIB_PREFIX."
    echo "The packages can be installed only on RedHat or CentOS."
    echo ""
    exit 1
esac

################################################################################
# Step 2: Check for the system-wide Libuuid library.

echo -n "Checking for Libuuid $PACKAGE_ARCH library... "
if rpm -q libuuid --queryformat '%{ARCH}' | grep -q "$PACKAGE_ARCH"; then
    echo "found."
else
    echo "not found. To install the library, use:"
    echo ""
    echo "   yum install libuuid.$PACKAGE_ARCH"
    echo ""
    exit 1
fi

################################################################################
# Step 3: Check for the system-wide OpenSSL library.

echo -n "Checking for OpenSSL $PACKAGE_ARCH library... "
OPENSSL_LIB="openssl"
if [[ "$PACKAGE_RH_VERSION" == "7" ]]; then
    OPENSSL_LIB="$OPENSSL_LIB-libs"
fi
if rpm -q $OPENSSL_LIB --queryformat '%{ARCH} %{VERSION}' | grep -q "$PACKAGE_ARCH"; then
    echo "found."
else
    echo "not found. To install the library, use:"
    echo ""
    echo "   yum install $OPENSSL_LIB.$PACKAGE_ARCH"
    echo ""
    exit 1
fi

################################################################################
# Step 4: Check whether the unimrcp service is active.

echo -n "Checking whether unimrcp service is active... "
if systemctl is-active unimrcp.service |  grep -w "active"; then
    echo -n "Stopping active unimrcp service... "
    systemctl stop unimrcp.service
    echo "done."
else
    echo "inactive."
fi

################################################################################
# Step 5: Install the APR library.

APR_PACKAGE=packages/uniapr-$APR_VERSION-1.$PACKAGE_DISTRIB.$PACKAGE_ARCH.rpm
if [[ -f $APR_PACKAGE ]]; then
    echo -n "Installing APR $APR_VERSION library... "
    echo ""
    rpm -Uvh --quiet $APR_PACKAGE
fi

################################################################################
# Step 6: Install the APR-Util library.

APR_UTIL_PACKAGE=packages/uniapr-util-$APR_UTIL_VERSION-1.$PACKAGE_DISTRIB.$PACKAGE_ARCH.rpm
if [[ -f $APR_UTIL_PACKAGE ]]; then
    echo -n "Installing APR-Util $APR_UTIL_VERSION library... "
    echo ""
    rpm -Uvh --quiet $APR_UTIL_PACKAGE
fi

################################################################################
# Step 7: Install the Sofia-SIP library.

SOFIA_SIP_PACKAGE=packages/unisofia-sip-$SOFIA_SIP_VERSION-1.$PACKAGE_DISTRIB.$PACKAGE_ARCH.rpm
if [[ -f $SOFIA_SIP_PACKAGE ]]; then
    echo -n "Installing Sofia-SIP $SOFIA_SIP_VERSION library... "
    echo ""
    rpm -Uvh --quiet $SOFIA_SIP_PACKAGE
fi

################################################################################
# Step 8: Install the UniMRCP common library.

UNIMRCP_COMMON_PACKAGE=packages/unimrcp-common-$UNIMRCP_VERSION-1.$PACKAGE_DISTRIB.$PACKAGE_ARCH.rpm
if [[ -f $UNIMRCP_COMMON_PACKAGE ]]; then
    echo -n "Installing UniMRCP Common $UNIMRCP_VERSION library... "
    echo ""
    rpm -Uvh --quiet $UNIMRCP_COMMON_PACKAGE
fi

################################################################################
# Step 9: Install the UniMRCP server library and application.

UNIMRCP_SERVER_PACKAGE=packages/unimrcp-server-$UNIMRCP_VERSION-1.$PACKAGE_DISTRIB.$PACKAGE_ARCH.rpm
if [[ -f $UNIMRCP_SERVER_PACKAGE ]]; then
    echo -n "Installing UniMRCP Server $UNIMRCP_VERSION library and application... "
    echo ""
    rpm -Uvh --quiet $UNIMRCP_SERVER_PACKAGE
fi

################################################################################
# Step 10: Install the gRPC-deps library.

UNIGRPC_DEPS_PACKAGE=packages/unigrpc-deps-$UNIGRPC_DEPS_VERSION-1.$PACKAGE_DISTRIB.$PACKAGE_ARCH.rpm
if [[ -f $UNIGRPC_DEPS_PACKAGE ]]; then
    echo -n "Installing gRPC deps $UNIGRPC_DEPS_VERSION library... "
    echo ""
    rpm -Uvh --quiet $UNIGRPC_DEPS_PACKAGE
fi

################################################################################
# Step 11: Install the gRPC library.

UNIGRPC_PACKAGE=packages/unigrpc-$UNIGRPC_VERSION-1.$PACKAGE_DISTRIB.$PACKAGE_ARCH.rpm
if [[ -f $UNIGRPC_PACKAGE ]]; then
    echo -n "Installing gRPC $UNIGRPC_DEPS_VERSION library... "
    echo ""
    rpm -Uvh --quiet $UNIGRPC_PACKAGE
fi

################################################################################
# Step 12: Install the license node generation tool.

UNILICNODEGEN_PACKAGE=packages/unilicnodegen-$UNILICNODEGEN_VERSION-1.$PACKAGE_DISTRIB.$PACKAGE_ARCH.rpm
if [[ -f $UNILICNODEGEN_PACKAGE ]]; then
    echo -n "Installing license node generation unilicnodegen $UNILICNODEGEN_VERSION tool... "
    echo ""
    rpm -Uvh --quiet $UNILICNODEGEN_PACKAGE
fi

################################################################################
# Step 13: Install the UniMRCP Orange SR plugin.

UNIMRCP_ORANGE_PACKAGE=packages/unimrcp-orange-sr-$UNIMRCP_ORANGE_VERSION-1.$PACKAGE_DISTRIB.$PACKAGE_ARCH.rpm
if [[ -f $UNIMRCP_ORANGE_PACKAGE ]]; then
    echo -n "Installing UniMRCP Orange SR $UNIMRCP_ORANGE_VERSION plugin... "
    echo ""
    rpm -Uvh --quiet $UNIMRCP_ORANGE_PACKAGE
fi

################################################################################
# Step 14: Install the UniMRCP client library and sample application.

UNIMRCP_CLIENT_PACKAGE=packages/unimrcp-client-$UNIMRCP_VERSION-1.$PACKAGE_DISTRIB.$PACKAGE_ARCH.rpm
if [[ -f $UNIMRCP_CLIENT_PACKAGE ]]; then
    echo -n "Installing UniMRCP Client $UNIMRCP_VERSION library and application... "
    echo ""
    rpm -Uvh --quiet $UNIMRCP_CLIENT_PACKAGE
fi

################################################################################
# Step 15: Install the UMC addons.

UMC_ADDONS_PACKAGE=packages/umc-addons-$UMC_ADDONS_VERSION-1.$PACKAGE_DISTRIB.noarch.rpm
if [[ -f $UMC_ADDONS_PACKAGE ]]; then
    echo -n "Installing UMC addons $UMC_ADDONS_VERSION... "
    echo ""
    rpm -Uvh --quiet $UMC_ADDONS_PACKAGE
fi

################################################################################
# Step 16: Done.

echo -n "Installation complete."
echo ""
exit 0
